﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace ImageToText
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
			radioButtonBase.Checked = true;
		}

		private void buttonBrowse_Click(object sender, EventArgs e)
		{
			if (textBoxFile.Text != null)
			{
				openFileDialog.FileName = textBoxFile.Text;
			}
			else
				openFileDialog.FileName = "";

			if (openFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
			{
				textBoxFile.Text = openFileDialog.FileName;
				textBoxResult.Clear();
			}
		}

		private void buttonEncode_Click(object sender, EventArgs e)
		{
			Clipboard.Clear();

			if (textBoxFile.Text == null || textBoxFile.Text.Length < 1)
			{
				textBoxResult.Text = @"File is not specified.";
				return;
			}

			try
			{
				FileStream fstream = File.Open(textBoxFile.Text, FileMode.Open, FileAccess.ReadWrite);
				if (fstream == null)
				{
					textBoxResult.Text = @"Unable to open the file.";
					return;
				}

				BinaryReader br = new BinaryReader(fstream);
				byte[] bytes = br.ReadBytes((int)fstream.Length);
				br.Close();

				if (!radioButtonHex.Checked)
				{
					string b64 = Convert.ToBase64String(bytes, 0, bytes.Length, Base64FormattingOptions.InsertLineBreaks);
					textBoxResult.Text = b64;
				}
				else
				{
					StringBuilder builder = new StringBuilder((int)bytes.Length * 2 + (bytes.Length / 76 + 1) * Environment.NewLine.Length);
					for (long i = 0; i < bytes.Length; i++)
					{
						builder.AppendFormat(String.Format("{0:X2}", bytes[i]));
						if ((i+1) % 38 == 0)
							builder.AppendFormat(Environment.NewLine);
					}

					textBoxResult.Text = builder.ToString();
				}

				Clipboard.SetText(textBoxResult.Text);
			}
			catch (Exception ex)
			{
				textBoxResult.Text = ex.Message;
			}
		}

		private void OnEncodingChanged(object sender, EventArgs e)
		{
			buttonEncode_Click(sender, e);
		}

		private void OnSizeChanged(object sender, EventArgs e)
		{
			textBoxResult.Size = new Size(ClientSize.Width - 26, ClientSize.Height - 140);

			radioButtonBase.Location = new System.Drawing.Point(13, ClientSize.Height - 80);
			radioButtonHex.Location = new System.Drawing.Point(13, ClientSize.Height - 60);

			label2.Location = new System.Drawing.Point(13, ClientSize.Height - 29);
			textBoxFile.Location = new System.Drawing.Point(68, ClientSize.Height - 32);
			textBoxFile.Size = new System.Drawing.Size(ClientSize.Width - 244, 20);

			buttonBrowse.Location = new System.Drawing.Point(ClientSize.Width - 168, ClientSize.Height - 34);
			buttonEncode.Location = new System.Drawing.Point(ClientSize.Width - 88, ClientSize.Height - 34);
		}
	}
}
